@@ -1,15 +1,12 @@
-import json
-
-from ConversationAgent import Stage, Agent, mock_client_human, __USER_TEXT__, MultiAgent, StageType
-from ConversationAgent.jieba_zh.analyse import tfidf
+from ConversationAgent import Stage, Agent, __USER_TEXT__, MultiAgent, StageType
+from ConversationAgent.ConversationAgent.jieba_zh.analyse import tfidf
 import re
-import requests
 
 __RE_STAGE__ = "__RE_STAGE__"
 __QA_STAGE__ = "__QA_STAGE__"
 __SWITCH_STAGE__ = StageType.SWITCH
 
-from ConversationAgent.nlp_tool import similar
+from ConversationAgent.ConversationAgent.nlp_tool import similar
 
 
 class QAStage(Stage):
